#ifndef NT2_INCLUDE_CONSTANTS_INV2PI_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_INV2PI_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/inv2pi.hpp>

#endif
